Struct eventstore::ReadStreamOptions
source · pub struct ReadStreamOptions { /* private fields */ }Implementations
sourceimpl ReadStreamOptions
impl ReadStreamOptions
sourcepub fn authenticated(self, credentials: Credentials) -> Self
pub fn authenticated(self, credentials: Credentials) -> Self
Performs the command with the given credentials.
pub fn requires_leader(self, requires_leader: bool) -> Self
pub fn deadline(self, deadline: Duration) -> Self
sourceimpl ReadStreamOptions
impl ReadStreamOptions
sourcepub fn forwards(self) -> Self
pub fn forwards(self) -> Self
Asks the command to read forward (toward the end of the stream). That’s the default behavior.
sourcepub fn backwards(self) -> Self
pub fn backwards(self) -> Self
Asks the command to read backward (toward the begining of the stream).
sourcepub fn position(self, position: StreamPosition<u64>) -> Self
pub fn position(self, position: StreamPosition<u64>) -> Self
Starts the read at the given event number. Default StreamPosition::Start
sourcepub fn resolve_link_tos(self) -> Self
pub fn resolve_link_tos(self) -> Self
When using projections, you can have links placed into another stream.
If you set true, the server will resolve those links and will return
the event that the link points to. Default: NoResolution.
pub fn max_count(self, max_count: usize) -> Self