pub struct RecordedEvent {
pub stream_id: String,
pub id: Uuid,
pub revision: u64,
pub event_type: String,
pub data: Bytes,
pub metadata: HashMap<String, String>,
pub custom_metadata: Bytes,
pub is_json: bool,
pub position: Position,
pub created: DateTime<Utc>,
}Expand description
Represents a previously written event.
Fields
stream_id: StringThe event stream that events belongs to.
id: UuidUnique identifier representing this event.
revision: u64Number of this event in the stream.
event_type: StringType of this event.
data: BytesPayload of this event.
metadata: HashMap<String, String>Representing the metadata associated with this event.
custom_metadata: BytesRepresenting the user-defined metadata associated with this event.
is_json: boolIndicates wheter the content is internally marked as JSON.
position: PositionAn event position in the $all stream.
created: DateTime<Utc>When the event was created in the database.
Implementations
Sourceimpl RecordedEvent
impl RecordedEvent
Sourcepub fn as_json<'a, T>(&'a self) -> Result<T>where
T: Deserialize<'a>,
pub fn as_json<'a, T>(&'a self) -> Result<T>where
T: Deserialize<'a>,
Tries to decode this event payload as a JSON object.